@@ -72,6 +72,13 @@ gth_metadata_provider_real_write (GthMetadataProvider   *self,
 }
 
 
+static int
+gth_metadata_provider_real_get_priority (GthMetadataProvider *self)
+{
+	return 10;
+}
+
+
 static void
 gth_metadata_provider_class_init (GthMetadataProviderClass * klass)
 {
@@ -79,6 +86,7 @@ gth_metadata_provider_class_init (GthMetadataProviderClass * klass)
 	GTH_METADATA_PROVIDER_CLASS (klass)->can_write = gth_metadata_provider_real_can_write;
 	GTH_METADATA_PROVIDER_CLASS (klass)->read = gth_metadata_provider_real_read;
 	GTH_METADATA_PROVIDER_CLASS (klass)->write = gth_metadata_provider_real_write;
+	GTH_METADATA_PROVIDER_CLASS (klass)->get_priority = gth_metadata_provider_real_get_priority;
 }
 
 
@@ -129,6 +137,13 @@ gth_metadata_provider_write (GthMetadataProvider   *self,
 }
 
 
+int
+gth_metadata_provider_get_priority (GthMetadataProvider *self)
+{
+	return GTH_METADATA_PROVIDER_GET_CLASS (self)->get_priority (self);
+}
+
+
 /* -- _g_query_metadata_async -- */
 
 
@@ -351,6 +366,7 @@ _g_write_metadata_async (GList                  *files, /* GthFileData * list */
 
 	wmd = g_new0 (WriteMetadataData, 1);
 	wmd->files = _g_object_list_ref (files);
+	wmd->flags = flags;
 	wmd->attributes = g_strdup (attributes);
 	wmd->attributes_v = gth_main_get_metadata_attributes (attributes);
 
